mlr_tuner_iaml: Multi-objective Hyperparameter Optimization, Feature...

mlr_tuner_iamlR Documentation

Multi-objective Hyperparameter Optimization, Feature Selection and Interaction and Monotonicity Constraints

Description

Performs joint multi-objective optimization of hyperparameters, feature selection and interaction and monotonicity constraints of a suitable mlr3::Learner.

This requires an appropriate mlr3::Learner, that allows for selecting features, and setting interaction and monotonicity constraints, e.g., xgboost.

Dictionary

This Tuner can be instantiated via the dictionary mlr_tuners or with the associated sugar function tnr():

TunerIAML$new()
mlr_tuners$get("iaml")
tnr("iaml")

Parameters

select_id

character(1)
ID of param in Learner that selects features.

interaction_id

character(1)
ID of param in Learner that sets interaction constraints.

monotone_id

character(1)
ID of param in Learner that sets monotonicity constraints.

batch_size

integer(1)
Maximum number of points to try in a batch.

Progress Bars

⁠$optimize()⁠ supports progress bars via the package progressr combined with a Terminator. Simply wrap the function in progressr::with_progress() to enable them. We recommend to use package progress as backend; enable with progressr::handlers("progress").

Logging

All Tuners use a logger (as implemented in lgr) from package bbotk. Use lgr::get_logger("bbotk") to access and control the logger.

Super class

mlr3tuning::Tuner -> TunerIAML

Methods

Public methods

Inherited methods

Method new()

Creates a new instance of this R6 class.

Usage
TunerIAML$new()

Method clone()

The objects of this class are cloneable with this method.

Usage
TunerIAML$clone(deep = FALSE)
Arguments
deep

Whether to make a deep clone.


sumny/iaml_prototype documentation built on May 16, 2023, 8:27 p.m.