| mlr_tuner_iaml | R Documentation |
Performs joint multi-objective optimization of hyperparameters, feature selection and interaction and monotonicity constraints of a suitable mlr3::Learner.
This requires an appropriate mlr3::Learner, that allows for selecting features, and setting interaction and monotonicity constraints, e.g., xgboost.
This Tuner can be instantiated via the dictionary
mlr_tuners or with the associated sugar function tnr():
TunerIAML$new()
mlr_tuners$get("iaml")
tnr("iaml")
select_idcharacter(1)
ID of param in Learner that selects features.
interaction_idcharacter(1)
ID of param in Learner that sets interaction constraints.
monotone_idcharacter(1)
ID of param in Learner that sets monotonicity constraints.
batch_sizeinteger(1)
Maximum number of points to try in a batch.
$optimize() supports progress bars via the package progressr
combined with a Terminator. Simply wrap the function in
progressr::with_progress() to enable them. We recommend to use package
progress as backend; enable with progressr::handlers("progress").
All Tuners use a logger (as implemented in lgr) from package
bbotk.
Use lgr::get_logger("bbotk") to access and control the logger.
mlr3tuning::Tuner -> TunerIAML
new()Creates a new instance of this R6 class.
TunerIAML$new()
clone()The objects of this class are cloneable with this method.
TunerIAML$clone(deep = FALSE)
deepWhether to make a deep clone.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.